KeyboardUIConfig class

Annotations

Constructors

KeyboardUIConfig({double digitBorderWidth = 1, EdgeInsetsGeometry keyboardRowMargin = const EdgeInsets.only(top: 15, left: 4, right: 4), EdgeInsetsGeometry digitInnerMargin = const EdgeInsets.all(24), Color primaryColor = Colors.white, Color digitFillColor = Colors.transparent, TextStyle digitTextStyle = const TextStyle(fontSize: 30, color: Colors.white), TextStyle deleteButtonTextStyle = const TextStyle(fontSize: 16, color: Colors.white), Size? keyboardSize})
const

Properties

deleteButtonTextStyle → TextStyle
final
digitBorderWidth → double
final
digitFillColor → Color
final
digitInnerMargin → EdgeInsetsGeometry
final
digitTextStyle → TextStyle
final
hashCode → int
The hash code for this object.
no setterinherited
keyboardRowMargin → EdgeInsetsGeometry
final
keyboardSize → Size?
final
primaryColor → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited